CooccurrenceFilteredModel
=========================

.. currentmodule:: pykeen.models

.. autoclass:: CooccurrenceFilteredModel
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~CooccurrenceFilteredModel.hpo_default

   .. rubric:: Methods Summary

   .. autosummary::

      ~CooccurrenceFilteredModel.collect_regularization_term
      ~CooccurrenceFilteredModel.predict_h
      ~CooccurrenceFilteredModel.predict_r
      ~CooccurrenceFilteredModel.predict_t
      ~CooccurrenceFilteredModel.score_h
      ~CooccurrenceFilteredModel.score_hrt
      ~CooccurrenceFilteredModel.score_r
      ~CooccurrenceFilteredModel.score_t

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default

   .. rubric:: Methods Documentation

   .. automethod:: collect_regularization_term
   .. automethod:: predict_h
   .. automethod:: predict_r
   .. automethod:: predict_t
   .. automethod:: score_h
   .. automethod:: score_hrt
   .. automethod:: score_r
   .. automethod:: score_t
